==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridKeydownEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridKeydownEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridKeydownEventArgsDescription, _super);
    function WebGridKeydownEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebGridKeydownEventArgsDescription.prototype.get_type = function () {
        return "WebGridKeydownEventArgs";
    };
    Object.defineProperty(WebGridKeydownEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridKeydownEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebGridKeydownEventArgsDescription.$t = markType(WebGridKeydownEventArgsDescription, 'WebGridKeydownEventArgsDescription', Description.$);
    WebGridKeydownEventArgsDescription.__marshalByValue = true;
    WebGridKeydownEventArgsDescription.__marshalByValueAlias = "GridKeydownEventArgs";
    return WebGridKeydownEventArgsDescription;
}(Description));
export { WebGridKeydownEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebGridKeydownEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridKeydownEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridKeydownEventArgsDescription, _super);
    function WebGridKeydownEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        return _this;
    }
    WebGridKeydownEventArgsDescription.prototype.get_type = function () {
        return "WebGridKeydownEventArgs";
    };
    Object.defineProperty(WebGridKeydownEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridKeydownEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebGridKeydownEventArgsDescription.$t = markType(WebGridKeydownEventArgsDescription, 'WebGridKeydownEventArgsDescription', Description.$);
    WebGridKeydownEventArgsDescription.__marshalByValue = true;
    WebGridKeydownEventArgsDescription.__marshalByValueAlias = "GridKeydownEventArgs";
    return WebGridKeydownEventArgsDescription;
}(Description));
export { WebGridKeydownEventArgsDescription };
